`timescale 1ns/1ns
module GMII_UDP_Loopback_Test(
	Clk,
	Rst_n,
	
	GMII_GTXC,
	GMII_TXD,
	GMII_TXEN,
	
	GMII_RXC,
	GMII_RXD,
	GMII_RXDV,

	ETH_Rst_n
);
	input Clk;
	input Rst_n;
	
	output GMII_GTXC;
	output [7:0]GMII_TXD;
	output GMII_TXEN;
	
	input GMII_RXC;
	input [7:0]GMII_RXD;
	input GMII_RXDV;
	

	output ETH_Rst_n;

	assign ETH_Rst_n = 1;
	wire [7:0]fifo_wrdata;
	wire fifo_wrreq;
	
  	reg TX_Go;
	wire clk125M_o;
	wire [15:0]rx_data_length;
	wire one_pkt_done;

	assign GMII_GTXC = GMII_RXC;
	
	//本机参数
	localparam local_mac = 48'h00_07_ed_ac_62_00;
	localparam local_ip = 32'hc0_a8_00_02;
	localparam local_port = 16'd5000;
	
	//远程主机参数
	localparam remote_mac = 48'hFF_FF_FF_FF_FF_FF;
	localparam remote_ip = 32'hc0_a8_00_03;
	localparam remote_port = 16'd6102;
	
//	pll pll(
//		.inclk0(Clk),
//		.c0(GMII_GTXC)
//	);
	
	//上电后先清零fifo
	reg [23:0]delay_cnt;
	always@(posedge Clk or negedge Rst_n)
	begin
		if(!Rst_n)
			delay_cnt <= 24'd0;
		else if(delay_cnt >= 24'hfffffd)
			delay_cnt <= delay_cnt;
		else
			delay_cnt <= delay_cnt + 1'd1;
	end
	
	wire fifo_aclr;
	assign fifo_aclr =(delay_cnt >= 24'd100)?1'b0:1'b1;	
	
	UDP_Send UDP_Send(
		.Clk(),
		.GMII_GTXC(GMII_GTXC),
		.GMII_TXD(GMII_TXD),
		.GMII_TXEN(GMII_TXEN),
		.Rst_n(Rst_n),
		.Go(one_pkt_done),
		.Tx_Done(),
		.data_length(rx_data_length),
		.des_ip(32'hc0_a8_00_03),
		.des_mac(48'hFF_FF_FF_FF_FF_FF),
		//.des_mac(48'h84_7B_EB_48_94_13),
		.des_port(16'd6102),
		.src_ip(32'hc0_a8_00_02),
		.src_mac(48'h00_07_ed_ac_62_00),
		.src_port(16'd5000),
		.wrclk(clk125M_o),
		.wrdata(fifo_wrdata),
		.wrreq(fifo_wrreq),
		.aclr(fifo_aclr),
		.wrusedw()
	);
	
  udp_gmii_rx udp_gmii_rx(
    .reset_n(Rst_n),

    .gmii_rx_en(1'b1),

    .local_mac(48'h00_07_ed_ac_62_00),
    .local_ip(32'hc0_a8_00_02),
    .local_port(16'd5000),

    .fifo_full(0),
    .fifo_wr(fifo_wrreq),
    .fifo_din(fifo_wrdata),
    .clk125M_o(clk125M_o),

    .exter_mac(),
    .exter_ip(),
    .exter_port(),
    .rx_data_length(rx_data_length),

    .one_pkt_done(one_pkt_done),
    .pkt_error(),
    .debug_cal_crc(),

    .gmii_rx_clk(GMII_RXC),
    .gmii_rxdv(GMII_RXDV),
    .gmii_rxd(GMII_RXD)
);
	
endmodule
